.. _versioning:

Versioning
==========

Versions numbers will comply with the
`Sementic Versioning (SemVer) specification`_ and will be
written in the form ``<major>.<minor>.<patch>``, where:

   * backwards incompatible API changes increments the major version
     (and resets the minor and patch versions).
   * backwards compatible API additions/changes increments the minor version
     (and resets the patch version).
   * bug fixes not affecting the API increments the patch version.


.. _Sementic Versioning (SemVer) specification: http://semver.org/
